@@ -26,6 +26,7 @@ export default withMermaid(
       logo: "/logo.svg",
       outline: "deep",
       nav: [
+        { text: "mise-tools", link: "https://mise-tools.jdx.dev/" },
         { text: "Dev Tools", link: "/dev-tools/" },
         { text: "Environments", link: "/environments/" },
         { text: "Tasks", link: "/tasks/" },
@@ -62,10 +63,11 @@ export default withMermaid(
               link: "/dev-tools/comparison-to-asdf",
             },
             { text: "Shims", link: "/dev-tools/shims" },
-            { text: "Aliases", link: "/dev-tools/aliases" },
+            { text: "Tool Aliases", link: "/dev-tools/aliases" },
             { text: "Tool Stubs", link: "/dev-tools/tool-stubs" },
             { text: "Registry", link: "/registry" },
             { text: "mise.lock Lockfile", link: "/dev-tools/mise-lock" },
+            { text: "Prepare", link: "/dev-tools/prepare" },
             {
               text: "Backend Architecture",
               link: "/dev-tools/backend_architecture",
@@ -117,6 +119,7 @@ export default withMermaid(
           text: "Environments",
           items: [
             { text: "Environment Variables", link: "/environments/" },
+            { text: "Shell Aliases", link: "/shell-aliases" },
             {
               text: "Secrets",
               link: "/environments/secrets/",
