@@ -1,5 +1,6 @@
+use crate::backend::SecurityFeature;
 use crate::backend::VersionInfo;
-use crate::backend::asset_detector;
+use crate::backend::asset_matcher::{self, Asset, ChecksumFetcher};
 use crate::backend::backend_type::BackendType;
 use crate::backend::platform_target::PlatformTarget;
 use crate::backend::static_helpers::{
@@ -7,7 +8,7 @@ use crate::backend::static_helpers::{
     template_string, try_with_v_prefix, verify_artifact,
 };
 use crate::cli::args::{BackendArg, ToolVersionType};
-use crate::config::Config;
+use crate::config::{Config, Settings};
 use crate::file;
 use crate::http::HTTP;
 use crate::install_context::InstallContext;
@@ -37,6 +38,14 @@ struct ReleaseAsset {
 const DEFAULT_GITHUB_API_BASE_URL: &str = "https://api.github.com";
 const DEFAULT_GITLAB_API_BASE_URL: &str = "https://gitlab.com/api/v4";
 
+/// Status returned from verification attempts
+enum VerificationStatus {
+    /// No attestations or provenance found (not an error, tool may not have them)
+    NoAttestations,
+    /// An error occurred during verification
+    Error(String),
+}
+
 /// Returns install-time-only option keys for GitHub/GitLab backend.
 pub fn install_time_option_keys() -> Vec<String> {
     vec![
@@ -60,10 +69,71 @@ impl Backend for UnifiedGitBackend {
         &self.ba
     }
 
-    async fn _list_remote_versions_with_info(
-        &self,
-        _config: &Arc<Config>,
-    ) -> Result<Vec<VersionInfo>> {
+    async fn security_info(&self) -> Vec<SecurityFeature> {
+        // Only report security features for GitHub (not GitLab yet)
+        if self.is_gitlab() {
+            return vec![];
+        }
+
+        let mut features = vec![];
+
+        // Get the latest release to check for security assets
+        let repo = self.ba.tool_name();
+        let opts = self.ba.opts();
+        let api_url = self.get_api_url(&opts);
+
+        let releases = github::list_releases_from_url(api_url.as_str(), &repo)
+            .await
+            .unwrap_or_default();
+
+        let latest_release = releases.first();
+
+        // Check for checksum files in assets
+        if let Some(release) = latest_release {
+            let has_checksum = release.assets.iter().any(|a| {
+                let name = a.name.to_lowercase();
+                name.contains("sha256")
+                    || name.contains("checksum")
+                    || name.ends_with(".sha256")
+                    || name.ends_with(".sha512")
+            });
+            if has_checksum {
+                features.push(SecurityFeature::Checksum {
+                    algorithm: Some("sha256".to_string()),
+                });
+            }
+        }
+
+        // Check for GitHub Attestations (assets with .sigstore.json or .sigstore extension)
+        if let Some(release) = latest_release {
+            let has_attestations = release.assets.iter().any(|a| {
+                let name = a.name.to_lowercase();
+                name.ends_with(".sigstore.json") || name.ends_with(".sigstore")
+            });
+            if has_attestations {
+                features.push(SecurityFeature::GithubAttestations {
+                    signer_workflow: None,
+                });
+            }
+        }
+
+        // Check for SLSA provenance (intoto.jsonl files)
+        if let Some(release) = latest_release {
+            let has_slsa = release.assets.iter().any(|a| {
+                let name = a.name.to_lowercase();
+                name.contains(".intoto.jsonl")
+                    || name.contains("provenance")
+                    || name.ends_with(".attestation")
+            });
+            if has_slsa {
+                features.push(SecurityFeature::Slsa { level: None });
+            }
+        }
+
+        features
+    }
+
+    async fn _list_remote_versions(&self, _config: &Arc<Config>) -> Result<Vec<VersionInfo>> {
         let repo = self.ba.tool_name();
         let id = self.ba.to_string();
         let opts = self.ba.opts();
@@ -352,9 +422,14 @@ impl UnifiedGitBackend {
 
         // Verify and install
         verify_artifact(tv, &file_path, opts, Some(ctx.pr.as_ref()))?;
-        install_artifact(tv, &file_path, opts, Some(ctx.pr.as_ref()))?;
         self.verify_checksum(ctx, tv, &file_path)?;
 
+        // Verify attestations or SLSA (check attestations first, fall back to SLSA)
+        self.verify_attestations_or_slsa(ctx, tv, &file_path)
+            .await?;
+
+        install_artifact(tv, &file_path, opts, Some(ctx.pr.as_ref()))?;
+
         if let Some(bins) = self.get_filter_bins(tv) {
             self.create_symlink_bin_dir(tv, bins)?;
         }
@@ -488,6 +563,13 @@ impl UnifiedGitBackend {
         let release = github::get_release_for_url(api_url, repo, version).await?;
         let available_assets: Vec<String> = release.assets.iter().map(|a| a.name.clone()).collect();
 
+        // Build asset list with URLs for checksum fetching
+        let assets_with_urls: Vec<Asset> = release
+            .assets
+            .iter()
+            .map(|a| Asset::new(&a.name, &a.browser_download_url))
+            .collect();
+
         // Try explicit pattern first
         if let Some(pattern) = lookup_platform_key_for_target(opts, "asset_pattern", target)
             .or_else(|| opts.get("asset_pattern").cloned())
@@ -507,16 +589,24 @@ impl UnifiedGitBackend {
                     )
                 })?;
 
+            // Try to get checksum from API digest or fetch from release assets
+            let digest = if asset.digest.is_some() {
+                asset.digest
+            } else {
+                self.try_fetch_checksum_from_assets(&assets_with_urls, &asset.name)
+                    .await
+            };
+
             return Ok(ReleaseAsset {
                 name: asset.name,
                 url: asset.browser_download_url,
                 url_api: asset.url,
-                digest: asset.digest,
+                digest,
             });
         }
 
         // Fall back to auto-detection for target platform
-        let asset_name = asset_detector::detect_asset_for_target(&available_assets, target)?;
+        let asset_name = asset_matcher::detect_asset_for_target(&available_assets, target)?;
         let asset = self
             .find_asset_case_insensitive(&release.assets, &asset_name, |a| &a.name)
             .ok_or_else(|| {
@@ -527,11 +617,19 @@ impl UnifiedGitBackend {
                 )
             })?;
 
+        // Try to get checksum from API digest or fetch from release assets
+        let digest = if asset.digest.is_some() {
+            asset.digest.clone()
+        } else {
+            self.try_fetch_checksum_from_assets(&assets_with_urls, &asset.name)
+                .await
+        };
+
         Ok(ReleaseAsset {
             name: asset.name.clone(),
             url: asset.browser_download_url.clone(),
             url_api: asset.url.clone(),
-            digest: asset.digest.clone(),
+            digest,
         })
     }
 
@@ -553,6 +651,14 @@ impl UnifiedGitBackend {
             .map(|a| a.name.clone())
             .collect();
 
+        // Build asset list with URLs for checksum fetching
+        let assets_with_urls: Vec<Asset> = release
+            .assets
+            .links
+            .iter()
+            .map(|a| Asset::new(&a.name, &a.direct_asset_url))
+            .collect();
+
         // Try explicit pattern first
         if let Some(pattern) = lookup_platform_key_for_target(opts, "asset_pattern", target)
             .or_else(|| opts.get("asset_pattern").cloned())
@@ -573,16 +679,21 @@ impl UnifiedGitBackend {
                     )
                 })?;
 
+            // GitLab doesn't provide digests, so try fetching from release assets
+            let digest = self
+                .try_fetch_checksum_from_assets(&assets_with_urls, &asset.name)
+                .await;
+
             return Ok(ReleaseAsset {
                 name: asset.name,
                 url: asset.direct_asset_url.clone(),
                 url_api: asset.url,
-                digest: None, // GitLab doesn't provide digests
+                digest,
             });
         }
 
         // Fall back to auto-detection for target platform
-        let asset_name = asset_detector::detect_asset_for_target(&available_assets, target)?;
+        let asset_name = asset_matcher::detect_asset_for_target(&available_assets, target)?;
         let asset = self
             .find_asset_case_insensitive(&release.assets.links, &asset_name, |a| &a.name)
             .ok_or_else(|| {
@@ -593,11 +704,16 @@ impl UnifiedGitBackend {
                 )
             })?;
 
+        // GitLab doesn't provide digests, so try fetching from release assets
+        let digest = self
+            .try_fetch_checksum_from_assets(&assets_with_urls, &asset.name)
+            .await;
+
         Ok(ReleaseAsset {
             name: asset.name.clone(),
             url: asset.direct_asset_url.clone(),
             url_api: asset.url.clone(),
-            digest: None, // GitLab doesn't provide digests
+            digest,
         })
     }
 
@@ -652,6 +768,35 @@ impl UnifiedGitBackend {
         }
     }
 
+    /// Tries to fetch a checksum for an asset from release checksum files.
+    ///
+    /// This method looks for checksum files (SHA256SUMS, *.sha256, etc.) in the release
+    /// assets and attempts to extract the checksum for the target asset.
+    ///
+    /// Returns the checksum in "sha256:hash" format if found, None otherwise.
+    async fn try_fetch_checksum_from_assets(
+        &self,
+        assets: &[Asset],
+        asset_name: &str,
+    ) -> Option<String> {
+        let fetcher = ChecksumFetcher::new(assets);
+        match fetcher.fetch_checksum_for(asset_name).await {
+            Some(result) => {
+                debug!(
+                    "Found checksum for {} from {}: {}",
+                    asset_name,
+                    result.source_file,
+                    result.to_string_formatted()
+                );
+                Some(result.to_string_formatted())
+            }
+            None => {
+                trace!("No checksum file found for {}", asset_name);
+                None
+            }
+        }
+    }
+
     fn get_filter_bins(&self, tv: &ToolVersion) -> Option<Vec<String>> {
         let opts = tv.request.options();
         let filter_bins = lookup_platform_key(&opts, "filter_bins")
@@ -705,6 +850,200 @@ impl UnifiedGitBackend {
         }
         Ok(())
     }
+
+    /// Verify artifact using GitHub attestations or SLSA provenance.
+    /// Tries attestations first, falls back to SLSA if no attestations found.
+    /// If verification is attempted and fails, it's a hard error.
+    async fn verify_attestations_or_slsa(
+        &self,
+        ctx: &InstallContext,
+        tv: &ToolVersion,
+        file_path: &std::path::Path,
+    ) -> Result<()> {
+        let settings = Settings::get();
+
+        // Only verify for GitHub repos (not GitLab)
+        if self.is_gitlab() {
+            return Ok(());
+        }
+
+        // Try GitHub attestations first (if enabled globally and for github backend)
+        if settings.github_attestations && settings.github.github_attestations {
+            match self
+                .try_verify_github_attestations(ctx, tv, file_path)
+                .await
+            {
+                Ok(true) => return Ok(()), // Verified successfully
+                Ok(false) => {
+                    // Attestations exist but verification failed - hard error
+                    return Err(eyre::eyre!(
+                        "GitHub attestations verification failed for {tv}"
+                    ));
+                }
+                Err(VerificationStatus::NoAttestations) => {
+                    // No attestations - fall through to try SLSA
+                    debug!("No GitHub attestations found for {tv}, trying SLSA");
+                }
+                Err(VerificationStatus::Error(e)) => {
+                    // Error during verification - hard error
+                    return Err(eyre::eyre!(
+                        "GitHub attestations verification error for {tv}: {e}"
+                    ));
+                }
+            }
+        }
+
+        // Fall back to SLSA provenance (if enabled globally and for github backend)
+        if settings.slsa && settings.github.slsa {
+            match self.try_verify_slsa(ctx, tv, file_path).await {
+                Ok(true) => return Ok(()), // Verified successfully
+                Ok(false) => {
+                    // Provenance exists but verification failed - hard error
+                    return Err(eyre::eyre!("SLSA provenance verification failed for {tv}"));
+                }
+                Err(VerificationStatus::NoAttestations) => {
+                    // No provenance found - this is fine
+                    debug!("No SLSA provenance found for {tv}");
+                }
+                Err(VerificationStatus::Error(e)) => {
+                    // Error during verification - hard error
+                    return Err(eyre::eyre!("SLSA verification error for {tv}: {e}"));
+                }
+            }
+        }
+
+        Ok(())
+    }
+
+    /// Try to verify GitHub attestations. Returns:
+    /// - Ok(true) if attestations exist and verified successfully
+    /// - Ok(false) if attestations exist but verification failed
+    /// - Err(NoAttestations) if no attestations found
+    /// - Err(Error) if an error occurred during verification
+    async fn try_verify_github_attestations(
+        &self,
+        ctx: &InstallContext,
+        tv: &ToolVersion,
+        file_path: &std::path::Path,
+    ) -> std::result::Result<bool, VerificationStatus> {
+        ctx.pr.set_message("verify GitHub attestations".to_string());
+
+        // Parse owner/repo from the repo string
+        let repo = self.repo();
+        let parts: Vec<&str> = repo.split('/').collect();
+        if parts.len() != 2 {
+            return Err(VerificationStatus::Error(format!(
+                "Invalid repo format: {repo}"
+            )));
+        }
+        let (owner, repo_name) = (parts[0], parts[1]);
+
+        match sigstore_verification::verify_github_attestation(
+            file_path, owner, repo_name, None, // No token - use public API
+            None, // We don't know the expected workflow
+        )
+        .await
+        {
+            Ok(verified) => {
+                if verified {
+                    debug!("GitHub attestations verified successfully for {tv}");
+                }
+                Ok(verified)
+            }
+            Err(sigstore_verification::AttestationError::NoAttestations) => {
+                Err(VerificationStatus::NoAttestations)
+            }
+            Err(e) => Err(VerificationStatus::Error(e.to_string())),
+        }
+    }
+
+    /// Try to verify SLSA provenance. Returns:
+    /// - Ok(true) if provenance exists and verified successfully
+    /// - Ok(false) if provenance exists but verification failed
+    /// - Err(NoAttestations) if no provenance found
+    /// - Err(Error) if an error occurred during verification
+    async fn try_verify_slsa(
+        &self,
+        ctx: &InstallContext,
+        tv: &ToolVersion,
+        file_path: &std::path::Path,
+    ) -> std::result::Result<bool, VerificationStatus> {
+        ctx.pr.set_message("verify SLSA provenance".to_string());
+
+        // Get the release to find provenance assets
+        let repo = self.repo();
+        let opts = tv.request.options();
+        let api_url = self.get_api_url(&opts);
+        let version = &tv.version;
+
+        // Try to get the release (with version prefix support)
+        let version_prefix = opts.get("version_prefix").map(|s| s.as_str());
+        let release = match try_with_v_prefix(version, version_prefix, |candidate| {
+            let api_url = api_url.clone();
+            let repo = repo.clone();
+            async move { github::get_release_for_url(&api_url, &repo, &candidate).await }
+        })
+        .await
+        {
+            Ok(r) => r,
+            Err(e) => {
+                return Err(VerificationStatus::Error(format!(
+                    "Failed to get release: {e}"
+                )));
+            }
+        };
+
+        // Find provenance assets in the release
+        let provenance_asset = release.assets.iter().find(|a| {
+            let name = a.name.to_lowercase();
+            name.contains(".intoto.jsonl")
+                || name.contains("provenance")
+                || name.ends_with(".attestation")
+        });
+
+        let provenance_asset = match provenance_asset {
+            Some(a) => a,
+            None => return Err(VerificationStatus::NoAttestations),
+        };
+
+        // Download the provenance file
+        let download_dir = tv.download_path();
+        let provenance_path = download_dir.join(&provenance_asset.name);
+
+        ctx.pr
+            .set_message(format!("download {}", provenance_asset.name));
+        if let Err(e) = HTTP
+            .download_file(
+                &provenance_asset.browser_download_url,
+                &provenance_path,
+                Some(ctx.pr.as_ref()),
+            )
+            .await
+        {
+            return Err(VerificationStatus::Error(format!(
+                "Failed to download provenance: {e}"
+            )));
+        }
+
+        ctx.pr.set_message("verify SLSA provenance".to_string());
+
+        // Verify the provenance
+        match sigstore_verification::verify_slsa_provenance(
+            file_path,
+            &provenance_path,
+            1, // Minimum SLSA level
+        )
+        .await
+        {
+            Ok(verified) => {
+                if verified {
+                    debug!("SLSA provenance verified successfully for {tv}");
+                }
+                Ok(verified)
+            }
+            Err(e) => Err(VerificationStatus::Error(e.to_string())),
+        }
+    }
 }
 
 /// Templates a string pattern with version and target platform values
