@@ -43,7 +43,7 @@ use std::sync::LazyLock as Lazy;
 
 pub mod aqua;
 pub mod asdf;
-pub mod asset_detector;
+pub mod asset_matcher;
 pub mod backend_type;
 pub mod cargo;
 pub mod conda;
@@ -135,7 +135,10 @@ pub enum SecurityFeature {
         #[serde(skip_serializing_if = "Option::is_none")]
         signer_workflow: Option<String>,
     },
-    Slsa,
+    Slsa {
+        #[serde(skip_serializing_if = "Option::is_none")]
+        level: Option<u8>,
+    },
     Cosign,
     Minisign {
         #[serde(skip_serializing_if = "Option::is_none")]
@@ -449,7 +452,7 @@ pub trait Backend: Debug + Send + Sync {
                     ba.to_string()
                 );
                 let versions = self
-                    ._list_remote_versions_with_info(config)
+                    ._list_remote_versions(config)
                     .await?
                     .into_iter()
                     .filter(|v| match v.version.parse::<ToolVersionType>() {
@@ -470,35 +473,9 @@ pub trait Backend: Debug + Send + Sync {
     }
 
     /// Backend implementation for fetching remote versions with metadata.
-    /// Default wraps `_list_remote_versions` with no timestamps.
-    /// Override this to provide timestamp information (e.g., aqua, github backends).
-    async fn _list_remote_versions_with_info(
-        &self,
-        config: &Arc<Config>,
-    ) -> eyre::Result<Vec<VersionInfo>> {
-        Ok(self
-            ._list_remote_versions(config)
-            .await?
-            .into_iter()
-            .map(|v| VersionInfo {
-                version: v,
-                ..Default::default()
-            })
-            .collect())
-    }
-
-    /// Backend implementation for fetching remote versions (without metadata).
-    /// Default delegates to `_list_remote_versions_with_info`.
-    /// Override this OR `_list_remote_versions_with_info` (not both needed).
-    /// WARNING: Implementing neither will cause infinite recursion.
-    async fn _list_remote_versions(&self, config: &Arc<Config>) -> eyre::Result<Vec<String>> {
-        Ok(self
-            ._list_remote_versions_with_info(config)
-            .await?
-            .into_iter()
-            .map(|v| v.version)
-            .collect())
-    }
+    /// Override this to provide version listing with optional timestamp information.
+    /// Return `VersionInfo` with `created_at: None` if timestamps are not available.
+    async fn _list_remote_versions(&self, config: &Arc<Config>) -> eyre::Result<Vec<VersionInfo>>;
 
     async fn latest_stable_version(&self, config: &Arc<Config>) -> eyre::Result<Option<String>> {
         self.latest_version(config, Some("latest".into())).await
@@ -1203,9 +1180,7 @@ pub trait Backend: Debug + Send + Sync {
                 );
             }
         } else if lockfile_enabled {
-            ctx.pr.set_message(format!("record size {filename}"));
-            let size = file.metadata()?.len();
-            platform_info.size = Some(size);
+            platform_info.size = Some(file.metadata()?.len());
         }
         Ok(())
     }
