@@ -4,6 +4,7 @@ use eyre::Result;
 use crate::env;
 
 mod clear;
+mod path;
 mod prune;
 
 /// Manage the mise cache
@@ -19,6 +20,7 @@ pub struct Cache {
 #[derive(Debug, Subcommand)]
 enum Commands {
     Clear(clear::CacheClear),
+    Path(path::CachePath),
     Prune(prune::CachePrune),
 }
 
@@ -26,6 +28,7 @@ impl Commands {
     pub fn run(self) -> Result<()> {
         match self {
             Self::Clear(cmd) => cmd.run(),
+            Self::Path(cmd) => cmd.run(),
             Self::Prune(cmd) => cmd.run(),
         }
     }
