@@ -1,13 +1,17 @@
+use std::collections::HashSet;
+use std::str::FromStr;
 use std::sync::Arc;
 
 use crate::cli::args::ToolArg;
 use crate::config::Config;
 use crate::config::Settings;
+use crate::duration::parse_into_timestamp;
 use crate::hooks::Hooks;
 use crate::toolset::{InstallOptions, ResolveOptions, ToolRequest, ToolSource, Toolset};
 use crate::{config, env, hooks};
 use eyre::Result;
 use itertools::Itertools;
+use jiff::Timestamp;
 
 /// Install a tool version
 ///
@@ -45,6 +49,12 @@ pub struct Install {
     #[clap(long, short, action = clap::ArgAction::Count)]
     verbose: u8,
 
+    /// Only install versions released before this date
+    ///
+    /// Supports absolute dates like "2024-06-01" and relative durations like "90d" or "1y".
+    #[clap(long, verbatim_doc_comment)]
+    before: Option<String>,
+
     /// Directly pipe stdin/stdout/stderr from plugin to user
     /// Sets --jobs=1
     #[clap(long, overrides_with = "jobs")]
@@ -74,19 +84,51 @@ impl Install {
         runtimes: &[ToolArg],
         original_tool_args: Vec<ToolArg>,
     ) -> Result<()> {
-        let tools = runtimes.iter().map(|ta| ta.ba.short.clone()).collect();
-        let mut ts = config
-            .get_tool_request_set()
-            .await?
-            .filter_by_tool(tools)
-            .into();
-        let tool_versions = self.get_requested_tool_versions(&ts, runtimes)?;
+        let trs = config.get_tool_request_set().await?;
+
+        // Expand wildcards (e.g., "pipx:*") to actual ToolArgs from config
+        let mut has_unmatched_wildcard = false;
+        let expanded_runtimes: Vec<ToolArg> = runtimes
+            .iter()
+            .flat_map(|ta| {
+                if let Some(backend_prefix) = ta.ba.short.strip_suffix(":*") {
+                    // Find all tools in config with this backend prefix
+                    let matching: Vec<_> = trs
+                        .tools
+                        .keys()
+                        .filter(|ba| {
+                            ba.short.starts_with(&format!("{backend_prefix}:"))
+                                && ba.tool_name != "*"
+                        })
+                        .filter_map(|ba| ToolArg::from_str(&ba.short).ok())
+                        .collect();
+                    if matching.is_empty() {
+                        warn!("no tools found in config matching {}", ta.ba.short);
+                        has_unmatched_wildcard = true;
+                    }
+                    return matching;
+                }
+                vec![ta.clone()]
+            })
+            .collect();
+
+        // If only wildcards were provided and none matched, exit early
+        if expanded_runtimes.is_empty() && has_unmatched_wildcard {
+            return Ok(());
+        }
+
+        let tools: HashSet<String> = expanded_runtimes
+            .iter()
+            .map(|ta| ta.ba.short.clone())
+            .collect();
+        let mut ts: Toolset = trs.filter_by_tool(tools).into();
+        let tool_versions = self.get_requested_tool_versions(&ts, &expanded_runtimes)?;
         let mut versions = if tool_versions.is_empty() {
             warn!("no runtimes to install");
             warn!("specify a version with `mise install <PLUGIN>@<VERSION>`");
             vec![]
         } else {
-            ts.install_all_versions(&mut config, tool_versions, &self.install_opts())
+            ts.install_all_versions(&mut config, tool_versions, &self.install_opts()?)
                 .await?
         };
         // because we may be installing a tool that is not in config, we need to restore the original tool args and reset everything
@@ -107,8 +149,8 @@ impl Install {
         Ok(())
     }
 
-    fn install_opts(&self) -> InstallOptions {
-        InstallOptions {
+    fn install_opts(&self) -> Result<InstallOptions> {
+        Ok(InstallOptions {
             force: self.force,
             jobs: self.jobs,
             raw: self.raw,
@@ -116,11 +158,23 @@ impl Install {
             resolve_options: ResolveOptions {
                 use_locked_version: true,
                 latest_versions: true,
+                before_date: self.get_before_date()?,
             },
             dry_run: self.dry_run,
             locked: Settings::get().locked,
             ..Default::default()
+        })
+    }
+
+    /// Get the before_date from CLI flag or settings
+    fn get_before_date(&self) -> Result<Option<Timestamp>> {
+        if let Some(before) = &self.before {
+            return Ok(Some(parse_into_timestamp(before)?));
         }
+        if let Some(before) = &Settings::get().install_before {
+            return Ok(Some(parse_into_timestamp(before)?));
+        }
+        Ok(None)
     }
 
     fn get_requested_tool_versions(
@@ -134,27 +188,25 @@ impl Install {
                 // user provided an explicit version
                 Some(tv) => requests.push(tv),
                 None => {
-                    if ta.tvr.is_none() {
-                        match ts.versions.get(ta.ba.as_ref()) {
-                            // the tool is in config so fetch the params from config
-                            // this may match multiple versions of one tool (e.g.: python)
-                            Some(tvl) => {
-                                for tvr in &tvl.requests {
-                                    requests.push(tvr.clone());
-                                }
-                            }
-                            // in this case the user specified a tool which is not in config
-                            // so we default to @latest with no options
-                            None => {
-                                let tvr = ToolRequest::Version {
-                                    backend: ta.ba.clone(),
-                                    version: "latest".into(),
-                                    options: ta.ba.opts(),
-                                    source: ToolSource::Argument,
-                                };
-                                requests.push(tvr);
+                    match ts.versions.get(ta.ba.as_ref()) {
+                        // the tool is in config so fetch the params from config
+                        // this may match multiple versions of one tool (e.g.: python)
+                        Some(tvl) => {
+                            for tvr in &tvl.requests {
+                                requests.push(tvr.clone());
                             }
                         }
+                        // in this case the user specified a tool which is not in config
+                        // so we default to @latest with no options
+                        None => {
+                            let tvr = ToolRequest::Version {
+                                backend: ta.ba.clone(),
+                                version: "latest".into(),
+                                options: ta.ba.opts(),
+                                source: ToolSource::Argument,
+                            };
+                            requests.push(tvr);
+                        }
                     }
                 }
             }
@@ -195,7 +247,7 @@ impl Install {
         } else {
             let mut ts = Toolset::from(trs.clone());
             measure!("install_all_versions", {
-                ts.install_all_versions(&mut config, versions, &self.install_opts())
+                ts.install_all_versions(&mut config, versions, &self.install_opts()?)
                     .await?
             })
         };
