@@ -5,14 +5,17 @@ use std::sync::Arc;
 use std::time::Duration;
 
 use super::args::ToolArg;
-use crate::cli::Cli;
+use crate::cli::{Cli, unescape_task_args};
 use crate::config::{Config, Settings};
 use crate::duration;
+use crate::prepare::{PrepareEngine, PrepareOptions};
+use crate::task::has_any_args_defined;
 use crate::task::task_helpers::task_needs_permit;
 use crate::task::task_list::{get_task_lists, resolve_depends};
 use crate::task::task_output::TaskOutput;
 use crate::task::task_output_handler::OutputHandler;
 use crate::task::{Deps, Task};
+use crate::toolset::{InstallOptions, ToolsetBuilder};
 use crate::ui::{ctrlc, style};
 use clap::{CommandFactory, ValueHint};
 use eyre::{Result, bail, eyre};
@@ -157,6 +160,10 @@ pub struct Run {
     #[clap(long, verbatim_doc_comment, env = "MISE_TASK_REMOTE_NO_CACHE")]
     pub no_cache: bool,
 
+    /// Skip automatic dependency preparation
+    #[clap(long)]
+    pub no_prepare: bool,
+
     /// Hides elapsed time after each task completes
     ///
     /// Default to always hide with `MISE_TASK_TIMINGS=0`
@@ -193,7 +200,7 @@ pub struct Run {
 
 impl Run {
     pub async fn run(mut self) -> Result<()> {
-        let config = Config::get().await?;
+        // Check help flags before doing any work
         if self.task == "-h" {
             self.get_clap_command().print_help()?;
             return Ok(());
@@ -203,39 +210,79 @@ impl Run {
             return Ok(());
         }
 
-        if !self.skip_deps {
-            self.skip_deps = Settings::get().task_skip_depends;
-        }
+        // Unescape task args early so we can check for help flags
+        self.args = unescape_task_args(&self.args);
 
-        // Check if --help or -h is in the args (before executing the task)
-        // This handles cases like: mise run --cd dir task --help
+        // Check if --help or -h is in the task args BEFORE toolset/prepare
         // NOTE: Only check self.args, not self.args_last, because args_last contains
-        // arguments after -- which should always be passed through to the task
-        let has_help_flag =
+        // arguments after explicit -- which should always be passed through to the task
+        let has_help_in_task_args =
             self.args.contains(&"--help".to_string()) || self.args.contains(&"-h".to_string());
 
-        if has_help_flag {
-            // Remove --help/-h from args to get the task
-            self.args.retain(|arg| arg != "--help" && arg != "-h");
-            self.args_last.retain(|arg| arg != "--help" && arg != "-h");
+        let mut config = Config::get().await?;
 
-            // Build args list to get the task
+        // Handle task help early to avoid unnecessary toolset/prepare work
+        if has_help_in_task_args {
+            // Build args list to get the task (filter out --help/-h for task lookup)
             let args = once(self.task.clone())
-                .chain(self.args.clone())
+                .chain(
+                    self.args
+                        .iter()
+                        .filter(|a| *a != "--help" && *a != "-h")
+                        .cloned(),
+                )
                 .collect_vec();
 
             let task_list = get_task_lists(&config, &args, false, false).await?;
 
             if let Some(task) = task_list.first() {
-                // Get usage spec and display help using usage library
+                // Get usage spec to check if task has defined args/flags
                 let spec = task.parse_usage_spec_for_display(&config).await?;
-                // Render help using usage library
-                println!("{}", usage::docs::cli::render_help(&spec, &spec.cmd, true));
+
+                // Only show mise help if the task has usage args/flags defined
+                // Otherwise, pass --help through to the underlying command
+                if has_any_args_defined(&spec) {
+                    // Render help using usage library
+                    println!("{}", usage::docs::cli::render_help(&spec, &spec.cmd, true));
+                    return Ok(());
+                }
+                // Task has no usage defined - fall through to execute with --help passed to task
             } else {
                 // No task found, show run command help
                 self.get_clap_command().print_long_help()?;
+                return Ok(());
             }
-            return Ok(());
+        }
+
+        // Build and install toolset so tools like npm are available for prepare
+        let mut ts = ToolsetBuilder::new()
+            .with_args(&self.tool)
+            .with_default_to_latest(true)
+            .build(&config)
+            .await?;
+
+        let opts = InstallOptions {
+            jobs: self.jobs,
+            raw: self.raw,
+            ..Default::default()
+        };
+        ts.install_missing_versions(&mut config, &opts).await?;
+
+        // Run auto-enabled prepare steps (unless --no-prepare)
+        if !self.no_prepare {
+            let env = ts.env_with_path(&config).await?;
+            let engine = PrepareEngine::new(config.clone())?;
+            engine
+                .run(PrepareOptions {
+                    auto_only: true, // Only run providers with auto=true
+                    env,
+                    ..Default::default()
+                })
+                .await?;
+        }
+
+        if !self.skip_deps {
+            self.skip_deps = Settings::get().task_skip_depends;
         }
 
         time!("run init");
