@@ -17,6 +17,7 @@ use crate::errors::Error::UntrustedConfig;
 use crate::file::display_path;
 use crate::hash::hash_to_str;
 use crate::hooks::Hook;
+use crate::prepare::PrepareConfig;
 use crate::redactions::Redactions;
 use crate::task::Task;
 use crate::toolset::{ToolRequest, ToolRequestSet, ToolSource, ToolVersionList, Toolset};
@@ -25,6 +26,7 @@ use crate::watch_files::WatchFile;
 use crate::{backend, config, dirs, env, file, hash};
 use eyre::{Result, eyre};
 use idiomatic_version::IdiomaticVersionFile;
+use indexmap::IndexMap;
 use serde_derive::Deserialize;
 use std::sync::LazyLock as Lazy;
 use tool_versions::ToolVersions;
@@ -98,6 +100,10 @@ pub trait ConfigFile: Debug + Send + Sync {
         Ok(Default::default())
     }
 
+    fn shell_aliases(&self) -> eyre::Result<IndexMap<String, String>> {
+        Ok(Default::default())
+    }
+
     fn task_config(&self) -> &TaskConfig {
         static DEFAULT_TASK_CONFIG: Lazy<TaskConfig> = Lazy::new(TaskConfig::default);
         &DEFAULT_TASK_CONFIG
@@ -119,6 +125,10 @@ pub trait ConfigFile: Debug + Send + Sync {
     fn hooks(&self) -> Result<Vec<Hook>> {
         Ok(Default::default())
     }
+
+    fn prepare_config(&self) -> Option<PrepareConfig> {
+        None
+    }
 }
 
 impl dyn ConfigFile {
