@@ -255,10 +255,7 @@ impl Backend for ZigPlugin {
         ]
     }
 
-    async fn _list_remote_versions_with_info(
-        &self,
-        _config: &Arc<Config>,
-    ) -> Result<Vec<VersionInfo>> {
+    async fn _list_remote_versions(&self, _config: &Arc<Config>) -> Result<Vec<VersionInfo>> {
         let indexes = [
             "https://ziglang.org/download/index.json",
             // "https://machengine.org/zig/index.json", // need to handle mach's CalVer
@@ -312,6 +309,7 @@ impl Backend for ZigPlugin {
         ctx: &InstallContext,
         mut tv: ToolVersion,
     ) -> Result<ToolVersion> {
+        ctx.pr.start_operations(3);
         let tarball_path = self.download(&tv, ctx.pr.as_ref()).await?;
         self.verify_checksum(ctx, &mut tv, &tarball_path)?;
         self.install(ctx, &tv, &tarball_path)?;
