@@ -15,6 +15,10 @@ const customGenerators: GeneratorIdentifier[] = [
     identifier: "alias",
     generator_name: "aliasGenerator",
   },
+  {
+    identifier: "shell_alias",
+    generator_name: "shellAliasGenerator",
+  },
   {
     identifier: "plugin",
     generator_name: "pluginGenerator",
@@ -126,6 +130,33 @@ function transformer<T extends ts.Node>(context: ts.TransformationContext) {
         }
       }
       const newNode = ts.visitEachChild(node, visit, context);
+      // Add generators to objects that should have them but don't
+      if (
+        newNode &&
+        has_property(newNode, '"name"') &&
+        has_property(newNode, '"description"') &&
+        !has_property(newNode, '"generators"') &&
+        !has_property(newNode, '"subcommands"') &&
+        !has_property(newNode, '"options"')
+      ) {
+        const id = get_identifier(newNode);
+        if (id) {
+          const objLiteralExpr = newNode as ts.ObjectLiteralExpression;
+          const generatorsProperty = ts.factory.createPropertyAssignment(
+            '"generators"',
+            id
+          );
+          const debounceProperty = ts.factory.createPropertyAssignment(
+            '"debounce"',
+            ts.factory.createIdentifier("true")
+          );
+          return ts.factory.updateObjectLiteralExpression(objLiteralExpr, [
+            ...objLiteralExpr.properties,
+            generatorsProperty,
+            debounceProperty,
+          ]);
+        }
+      }
       if (
         newNode &&
         has_property(newNode, '"generators"') &&
